@@ -61,7 +61,7 @@ QPoint ModuleWidget::componentPos(const StructureComponent *component) const
 	int cellx = 0, celly = 0;
 	colXPos(component->x(), &cellx);
 	rowYPos(component->y(), &celly);
-	
+
 	return QPoint(cellx, celly);
 }
 
@@ -70,7 +70,7 @@ QPoint ModuleWidget::portPos(const ModulePort *port) const
 	int cellx = 0, celly = 0;
 	colXPos(port->owner->x() + port->drawsegment, &cellx);
 	rowYPos(port->owner->y(), &celly);
-	
+
 	return QPoint(cellx, celly);
 }
 
@@ -92,7 +92,7 @@ void ModuleWidget::findAt(int windowX, int windowY,
 	int y = findRow(windowY);
 
 	component = structure->componentAt(x, y, false);
-	
+
 	if(component)
 	{
 		int cellx = 0, celly = 0;
@@ -111,7 +111,7 @@ void ModuleWidget::selectComponent( StructureComponent *component, bool onlyThis
 	beginUpdate();
 	if(onlyThis)
 		unselectAll();
-	
+
 	if(!(component->selected()))
 	{
 		component->setSelected(true);
@@ -145,7 +145,7 @@ void ModuleWidget::mousePressEvent( QMouseEvent *e )
 			{
 				// user clicked in port
 				selectPort(port);
-				
+
 				delete activeTool;
 				activeTool = new ConnectPortsTool(this, port);
 			}
@@ -206,7 +206,7 @@ void ModuleWidget::selectPort( ModulePort *port, bool newMode )
 			emit portSelected(0L);
 		selectedPort = 0L;
 	}
-	
+
 	if(port)
 	{
 		port->selected = newMode;
@@ -215,7 +215,7 @@ void ModuleWidget::selectPort( ModulePort *port, bool newMode )
 		selectedPort->owner->redraw();
 	}
 	emit portSelected(port); // FIXME: should be "portSelectionChanged"
-	
+
 	endUpdate();
 }
 
@@ -279,7 +279,7 @@ void ModuleWidget::unselectAll()
 void ModuleWidget::setSelectAll(bool newstate)
 {
 	std::list<StructureComponent *>::iterator module;
-	
+
 	for(module = structure->getComponentList()->begin();
         module != structure->getComponentList()->end(); module++)
 	{
@@ -310,7 +310,7 @@ void ModuleWidget::endUpdate()
 void ModuleWidget::redrawRect(int x, int y, int width, int height)
 {
 	QRect r = QRect(x, y, width, height);
-	
+
 	if(!updateDepth)
 	{
 		redrawCells(r);
@@ -363,7 +363,7 @@ void ModuleWidget::reRoute()
 
 	std::map<long, ModulePort *> portmap;
 
-	for(pi = portlist.begin(); pi != portlist.end(); pi++)
+	for(pi = portlist.begin(); pi != portlist.end(); ++pi)
 	{
 		ModulePort *port = *pi;
 
@@ -386,10 +386,10 @@ void ModuleWidget::reRoute()
 	vector<long> owner(portlist.size());
 
 	long maxcolor = 0;
-	for(pi = portlist.begin(); pi != portlist.end(); pi++)
+	for(pi = portlist.begin(); pi != portlist.end(); ++pi)
 		color[*pi] = maxcolor++;
 
-	for(pi = portlist.begin(); pi != portlist.end(); pi++)
+	for(pi = portlist.begin(); pi != portlist.end(); ++pi)
 	{
 		ModulePort *src = *pi;
 		unsigned long c;
@@ -418,7 +418,7 @@ void ModuleWidget::reRoute()
 		}
 	}
 
-	for(pi = portlist.begin(); pi != portlist.end(); pi++)
+	for(pi = portlist.begin(); pi != portlist.end(); ++pi)
 	{
 		ModulePort *p = *pi;
 
@@ -450,7 +450,7 @@ void ModuleWidget::reRoute()
 					route_owner = autorouter->connect(x1, y1, x2, y2, route_owner);
 				}
 			}
-			
+
 			delete conn;
 		}
 	}
@@ -588,12 +588,12 @@ void ModuleWidget::reInit()
 void ModuleWidget::delModule()
 {
 	int numSelected = structure->countSelected();
-	
+
 	if(!numSelected) return;
 
 	if(KMessageBox::warningContinueCancel(0,
-		i18n("Delete %n selected module, port or connection? (No undo possible!)",
-		     "Delete %n selected modules, ports and connections? (No undo possible!)",
+		i18n("Delete %n selected module, port or connection? (No undo possible.)",
+		     "Delete %n selected modules, ports and connections? (No undo possible.)",
 		     numSelected), QString::null, i18n("&Delete")) == KMessageBox::Continue)
 	{
 		selectPort(0L);
