@@ -25,7 +25,7 @@
 
 #include <qslider.h>
 
-class KFader : virtual public QSlider
+class KFader : public QSlider
 {
 	Q_OBJECT
 	protected:
@@ -42,3 +42,5 @@ class KFader : virtual public QSlider
 };
 
 #endif /* KFADER_H */
+
+// vim: sw=4 ts=4
