@@ -2,6 +2,7 @@
 
     Copyright (C) 2000 Stefan Westerfeld
                        stefan@space.twc.de
+                  2002 Matthias Kretz <kretz@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -30,12 +31,14 @@
 namespace Arts {
 
 class KLineEdit_impl : virtual public Arts::LineEdit_skel,
-                       virtual public Arts::KWidget_impl
+                       public Arts::KWidget_impl
 {
 protected:
-	KLineEdit *klineedit;
+	KLineEdit * _klineedit;
+
 public:
-	KLineEdit_impl(KLineEdit *le = 0);
+	KLineEdit_impl( KLineEdit * w = 0 );
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string& newCaption);
@@ -56,3 +59,5 @@ public slots:
 }
 
 #endif
+
+// vim: sw=4 ts=4
