@@ -98,7 +98,7 @@ ModuleDef StructureBuilder_impl::createTypeInfo(StructureDesc structure)
 
 		// if we inherited the port from a parent interface, we don't need to
 		// list it in our interface description
-		if(pi->inheritedInterface() == "")
+		if(pi->inheritedInterface().empty())
 		{
 			AttributeDef ad;
 			ad.name = pi->name();
