@@ -1402,7 +1402,7 @@ vector<string> *StructurePortDesc_impl::saveToList()
 	sqprintf(list,"y=%ld",_y);
 	sqprintf(list,"position=%ld",_position);
 
-	if(_inheritedInterface != "")
+	if(!_inheritedInterface.empty())
 		sqprintf(list, "interface=%s",_inheritedInterface.c_str());
 
 	sqprintf(list,"type");
