@@ -18,7 +18,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <qcursor.h>
@@ -29,7 +29,7 @@
 
 extern "C"
 {
-  KPanelApplet* init( QWidget *parent, const QString configFile)
+  KDE_EXPORT KPanelApplet* init( QWidget *parent, const QString configFile)
   {
     KGlobal::locale()->insertCatalogue("artscontrol");
     return new ArtsControlApplet(configFile, KPanelApplet::Normal,
