@@ -1,7 +1,9 @@
     /*
 
     Copyright (C) 2001 Stefan Westerfeld
-	                   <stefan@space.twc.de>
+                       <stefan@space.twc.de>
+                  2003 Matthias Kretz <kretz@kde.org>
+		  2003 Arnold Krille <arnold@arnoldarts.de
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -23,32 +25,33 @@
 #define ARTS_ENVIRONMENT_VIEW_H
 
 #include "artsmodules.h"
-#include <qvbox.h>
+
+#include "templateview.h"
 
 class QListBoxItem;
-class QListBox;
+class KListBox;
 
-class EnvironmentView : public QVBox {
+class EnvironmentView : public Template_ArtsView {
 	Q_OBJECT
 protected:
 	Arts::Environment::Container container;
-	QListBox *listBox;
+	KListBox *listBox;
 	QString defaultEnvFileName;
 
 public:
-	EnvironmentView(Arts::Environment::Container container);
-	void closeEvent(QCloseEvent *e);
+	EnvironmentView( Arts::Environment::Container container, QWidget* =0, const char* =0 );
 
 public slots:
 	void view(QListBoxItem *i);
 	void addMixer();
+	void addEffectRack();
 	void delItem();
 	void update();
 	void load();
 	void save();
 
-signals:
-	void closed();
 };
 
+Arts::Environment::Container defaultEnvironment();
+
 #endif /* ARTS_ENVIRONMENT_VIEW_H */
