@@ -18,6 +18,7 @@
 #include "dynamicplaylist.h"
 #include "collectionlist.h"
 #include "playlistcollection.h"
+#include "tracksequencemanager.h"
 
 class PlaylistDirtyObserver : public PlaylistObserver
 {
@@ -43,10 +44,12 @@ DynamicPlaylist::DynamicPlaylist(const PlaylistList &playlists,
                                  PlaylistCollection *collection,
                                  const QString &name,
                                  const QString &iconName,
-				 bool setupPlaylist) :
+                                 bool setupPlaylist,
+                                 bool synchronizePlaying) :
     Playlist(collection, true),
     m_playlists(playlists),
-    m_dirty(true)
+    m_dirty(true),
+    m_synchronizePlaying(synchronizePlaying)
 {
     if(setupPlaylist)
         collection->setupPlaylist(this, iconName);
@@ -62,6 +65,8 @@ DynamicPlaylist::DynamicPlaylist(const PlaylistList &playlists,
 
 DynamicPlaylist::~DynamicPlaylist()
 {
+    lower();
+
     for(QValueList<PlaylistObserver *>::ConstIterator it = m_observers.begin();
         it != m_observers.end();
         ++it)
@@ -70,6 +75,12 @@ DynamicPlaylist::~DynamicPlaylist()
     }
 }
 
+void DynamicPlaylist::setPlaylists(const PlaylistList &playlists)
+{
+    m_playlists = playlists;
+    updateItems();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // public slots
 ////////////////////////////////////////////////////////////////////////////////
@@ -82,6 +93,33 @@ void DynamicPlaylist::slotReload()
     checkUpdateItems();
 }
 
+void DynamicPlaylist::lower(QWidget *top)
+{
+    if(top == this)
+	return;
+
+    if(playing()) {
+        PlaylistList l;
+        l.append(this);
+        for(PlaylistList::Iterator it = m_playlists.begin();
+            it != m_playlists.end(); ++it)
+        {
+            (*it)->synchronizePlayingItems(l, true);
+        }
+    }
+
+    PlaylistItemList list = PlaylistItem::playingItems();
+    for(PlaylistItemList::Iterator it = list.begin(); it != list.end(); ++it) {
+        if((*it)->playlist() == this) {
+            list.remove(it);
+            break;
+        }
+    }
+
+    if(!list.isEmpty())
+        TrackSequenceManager::instance()->setCurrentPlaylist(list.front()->playlist());
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // protected methods
 ////////////////////////////////////////////////////////////////////////////////
@@ -119,6 +157,11 @@ void DynamicPlaylist::updateItems()
     }
 }
 
+bool DynamicPlaylist::synchronizePlaying() const
+{
+    return m_synchronizePlaying;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // private methods
 ////////////////////////////////////////////////////////////////////////////////
@@ -144,6 +187,8 @@ void DynamicPlaylist::slotUpdateItems()
 
     clear();
     createItems(m_siblings);
+    if(m_synchronizePlaying)
+        synchronizePlayingItems(m_playlists, true);
 }
 
 #include "dynamicplaylist.moc"
