@@ -1,7 +1,6 @@
 /***************************************************************************
-    begin                : Sat Feb 9 2003
-    copyright            : (C) 2003 by Tim Jansen
-    email                : tim@tjansen.de
+    copyright            : (C) 2004 Scott Wheeler
+    email                : wheeler@kde.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -17,14 +16,12 @@
 #ifndef GSTREAMERPLAYER_H
 #define GSTREAMERPLAYER_H
 
-#include <config.h>
+#include "config.h"
 
 #if HAVE_GSTREAMER
 
-#include <kde/gstplay/play.h>
-
+#include <gst/gst.h>
 #include <qstring.h>
-
 #include "player.h"
 
 class GStreamerPlayer : public Player
@@ -50,28 +47,35 @@ public:
     virtual void seek(int seekTime);
     virtual void seekPosition(int position);
 
+    virtual void pause();
 public slots:
-    void pause();
-    void stop();
-
-private slots:
-    void slotSetPosition(long long d) { m_positionNs = d; }
-    void slotSetDuration(long long d) { m_durationNs = d; }
-    void slotStopIfNotPlaying();
+    virtual void stop();
 
 private:
-    void setupPlayer();
+    void setupPipeline();
 
-    KDE::GSTPlay::Play *m_player;
-    unsigned long long m_duration;
+#if GSTREAMER_VERSION == 8
 
-    long long m_positionNs; // in ns
-    long long m_durationNs; // in ns
+    void readConfig();
+    long long time(GstQueryType type) const;
 
-    QString m_currentFile;
-    float m_currentVolume;
+    QString m_sinkName;
+    GstElement *m_pipeline;
+    GstElement *m_source;
+    GstElement *m_decoder;
+    GstElement *m_volume;
+    GstElement *m_sink;
+
+#else
+
+    enum TimeQuery { CurrentPosition, TotalLength };
+    long long time(TimeQuery type) const;
+
+    GstState state() const;
+    GstElement *m_playbin;
+
+#endif
 };
 
 #endif
-
 #endif
