@@ -54,6 +54,10 @@ Tag::Tag(const QString &fileName) :
     m_bitrate(0),
     m_isValid(false)
 {
+    // using qDebug here since we want this to show up in non-debug builds as well
+
+    qDebug("Reading tag for %s", fileName.local8Bit().data());
+
     if(MediaFiles::isMP3(fileName)) {
         TagLib::MPEG::File file(QFile::encodeName(fileName).data());
         if(file.isValid())
@@ -62,21 +66,21 @@ Tag::Tag(const QString &fileName) :
 
     else if(MediaFiles::isFLAC(fileName)) {
         TagLib::FLAC::File file(QFile::encodeName(fileName).data());
-        if(file.isOpen())
+        if(file.isValid())
             setup(&file);
     }
 #ifdef TAGLIB_1_3
     else if(MediaFiles::isMPC(fileName)) {
         kdDebug(65432) << "Trying to resolve Musepack file" << endl;
         TagLib::MPC::File file(QFile::encodeName(fileName).data());
-        if(file.isOpen())
+        if(file.isValid())
             setup(&file);
     }
 #endif
 #ifdef TAGLIB_1_2
     else if(MediaFiles::isOggFLAC(fileName)) {
         TagLib::Ogg::FLAC::File file(QFile::encodeName(fileName).data());
-        if(file.isOpen())
+        if(file.isValid())
             setup(&file);
     }
 #endif
