@@ -37,7 +37,6 @@ Q_OBJECT
 signals:
   void addJob(Job *job, const QString &name);
   void updateProgress(int id, int progress);
-  void jobIsDone(Job *job, const QString &extension);
   void jobsChanged();
 
 public:
@@ -50,7 +49,7 @@ public slots:
   void removeJob(int id);
   void encodeWav(Job *job);
   void loadSettings();
-	void loadEncoder( int encoder );
+  EncoderPrefs* loadEncoder( int encoder );
 
 private slots:
   void receivedThreadOutput(KProcess *process, char *buffer, int buflen);
@@ -62,7 +61,6 @@ private:
   QPtrList<KShellProcess> threads;
   QMap<KShellProcess*, Job*> jobs;
 
-  EncoderPrefs *prefs;
   int reportCount;
 };
 
