@@ -63,19 +63,20 @@ KAviPlugin::KAviPlugin(QObject *parent, const char *name,
 
     item = addItemInfo(group, "Resolution", i18n("Resolution"), QVariant::Size);
 
-    item = addItemInfo(group, "Frame rate", i18n("Frame rate"), QVariant::Int);
+    item = addItemInfo(group, "Frame rate", i18n("Frame Rate"), QVariant::Int);
     setSuffix(item, i18n("fps"));
 
-    item = addItemInfo(group, "Video codec", i18n("Video codec"), QVariant::String);
-    item = addItemInfo(group, "Audio codec", i18n("Audio codec"), QVariant::String);
+    item = addItemInfo(group, "Video codec", i18n("Video Codec"), QVariant::String);
+    item = addItemInfo(group, "Audio codec", i18n("Audio Codec"), QVariant::String);
+
 }
 
 bool KAviPlugin::read_avi()
 {
-    static const char *sig_riff = "RIFF";
-    static const char *sig_avi  = "AVI ";
-    static const char *sig_list = "LIST";
-    static const char *sig_junk = "JUNK";
+    static const char sig_riff[] = "RIFF";
+    static const char sig_avi[]  = "AVI ";
+    static const char sig_list[] = "LIST";
+    static const char sig_junk[] = "JUNK";
     uint32_t dwbuf1;
 
     done_avih = false;
@@ -150,9 +151,9 @@ bool KAviPlugin::read_avi()
 
 bool KAviPlugin::read_list()
 {
-    static const char *sig_hdrl = "hdrl";   // header list
-    static const char *sig_strl = "strl";   // ...list
-    static const char *sig_movi = "movi";   // movie list
+    const char sig_hdrl[] = "hdrl";   // header list
+    const char sig_strl[] = "strl";   // ...list
+    const char sig_movi[] = "movi";   // movie list
 
     uint32_t dwbuf1;
     char charbuf1[5];
@@ -194,7 +195,7 @@ bool KAviPlugin::read_list()
 
 bool KAviPlugin::read_avih()
 {
-    static const char *sig_avih = "avih";   // header list
+    static const char sig_avih[] = "avih";   // header list
 
     uint32_t dwbuf1;
     char charbuf1[5];
@@ -233,18 +234,17 @@ bool KAviPlugin::read_avih()
 
 bool KAviPlugin::read_strl()
 {
-    static const char *sig_strh = "strh";
-    static const char *sig_strf = "strf";
-    static const char *sig_strd = "strd";
-    static const char *sig_strn = "strn";
-    static const char *sig_list = "LIST";
-    static const char *sig_junk = "JUNK";
+    static const char sig_strh[] = "strh";
+    static const char sig_strf[] = "strf";
+    //static const char sig_strd[] = "strd";
+    static const char sig_strn[] = "strn";
+    static const char sig_list[] = "LIST";
+    static const char sig_junk[] = "JUNK";
 
     kdDebug(7034) << "in strl handler\n";
 
     uint32_t dwbuf1;    // buffer for block sizes
     char charbuf1[5];
-    char charbuf2[5];
 
     // loop through blocks
     int counter = 0;
@@ -336,8 +336,8 @@ bool KAviPlugin::read_strl()
 
 bool KAviPlugin::read_strh(uint32_t blocksize)
 {
-    static const char *sig_vids = "vids";   // ...video
-    static const char *sig_auds = "auds";   // ...audio
+    static const char sig_vids[] = "vids";   // ...video
+    static const char sig_auds[] = "auds";   // ...audio
 
     uint32_t strh_flags;
     uint32_t strh_reserved1;
@@ -427,19 +427,39 @@ bool KAviPlugin::read_strf(uint32_t blocksize)
 
 
 
-QString KAviPlugin::resolve_audio(uint16_t id) const
+const char * KAviPlugin::resolve_audio(uint16_t id)
 {
+    /*
+        this really wants to use some sort of KDE global
+        list.  To avoid bloat for the moment it only does
+        a few common codecs
+    */
+
+    static const char codec_unknown[] = I18N_NOOP("Unknown");
+    static const char codec_01[]  = "Microsoft PCM";
+    static const char codec_02[]  = "Microsoft ADPCM";
+    static const char codec_50[]  = "MPEG";
+    static const char codec_55[]  = "MP3";
+    static const char codec_92[]  = "AC3";
+    static const char codec_160[] = "WMA1";
+    static const char codec_161[] = "WMA2";
+    static const char codec_162[] = "WMA3";
+    static const char codec_2000[] = "DVM";
     switch (id) {
-    case 0x00 : return i18n("Unknown wave format"); break;
-    case 0x01 : return i18n("Wave (PCM)"); break;
-    case 0x02 : return i18n("Wave (ADPCM)"); break;
-    case 0x50 : return i18n("MPEG"); break;
-    case 0x55 : return i18n("MP3"); break;
-    case 0x92 : return i18n("AC3"); break;
-    default : return i18n("unknown codec", "Unknown");
+    case 0x000 : return codec_unknown; break;
+    case 0x001 : return codec_01; break;
+    case 0x002 : return codec_02; break;
+    case 0x050 : return codec_50; break;
+    case 0x055 : return codec_55; break;
+    case 0x092 : return codec_92; break;
+    case 0x160 : return codec_160; break;
+    case 0x161 : return codec_161; break;
+    case 0x162 : return codec_162; break;
+    case 0x2000 : return codec_2000; break;
+    default : return codec_unknown;
     }
 
-    return QString();
+    return NULL;
 }
 
 
@@ -455,6 +475,12 @@ bool KAviPlugin::readInfo( KFileMetaInfo& info, uint /*what*/)
     /***************************************************/
     // sort out the file
 
+    if (f.isOpen())
+        f.close();
+
+    if ( info.path().isEmpty() ) // remote file
+        return false;
+
     f.setName(info.path());
 
     // open file, set up stream and set endianness
@@ -485,7 +511,9 @@ bool KAviPlugin::readInfo( KFileMetaInfo& info, uint /*what*/)
 
         KFileMetaInfoGroup group = appendGroup(info, "Technical");
 
-        appendItem(group, "Frame rate", int(1000000 / avih_microsecperframe));
+	if (0 != avih_microsecperframe) {
+	    appendItem(group, "Frame rate", int(1000000 / avih_microsecperframe));
+	}
         appendItem(group, "Resolution", QSize(avih_width, avih_height));
 
         // work out and add length
@@ -496,15 +524,16 @@ bool KAviPlugin::readInfo( KFileMetaInfo& info, uint /*what*/)
         if (strlen(handler_vids) > 0)
             appendItem(group, "Video codec", handler_vids);
         else
-            appendItem(group, "Video codec", i18n("unknown codec", "Unknown"));
+            appendItem(group, "Video codec", i18n("Unknown"));
 
         if (done_audio)
-            appendItem(group, "Audio codec", resolve_audio(handler_audio));
+            appendItem(group, "Audio codec", i18n(resolve_audio(handler_audio)));
         else
-            appendItem(group, "Audio codec", i18n("no codec", "None"));
+            appendItem(group, "Audio codec", i18n("None"));
 
     }
 
+    f.close();
     return true;
 }
 
