@@ -75,7 +75,7 @@ extern "C"
 }
 
 int KMixApplet::s_instCount = 0;
-QPtrList<Mixer> KMixApplet::s_mixers;
+//<Mixer> KMixApplet::Mixer::mixers();
 
 static const QColor highColor = KGlobalSettings::baseColor();
 static const QColor lowColor = KGlobalSettings::highlightColor();
@@ -158,15 +158,16 @@ KMixApplet::KMixApplet( const QString& configFile, Type t,
                          APP_VERSION, "Mini Sound Mixer Applet", KAboutData::License_GPL,
                          I18N_NOOP( "(c) 1996-2000 Christian Esken\n(c) 2000-2003 Christian Esken, Stefan Schimanski") )
 {
+    setBackgroundOrigin(AncestorOrigin);
     kdDebug(67100) << "KMixApplet::KMixApplet instancing Applet. Old s_instCount="<< s_instCount << " configfile=" << configFile << endl;
     //kdDebug(67100) << "KMixApplet::KMixApplet()" << endl;
     _layout = new QHBoxLayout(this); // it will always only be one item in it, so we don't care whether it is HBox or VBox
 
     // init static vars
     if ( s_instCount == 0) {
-        s_mixers.setAutoDelete( TRUE );
+        Mixer::mixers().setAutoDelete( TRUE );
 	QString dummyStringHwinfo;
-	MixerToolBox::initMixer(s_mixers, false, dummyStringHwinfo);
+	MixerToolBox::initMixer(Mixer::mixers(), false, dummyStringHwinfo);
     }	
     s_instCount++;
     kdDebug(67100) << "KMixApplet::KMixApplet instancing Applet, s_instCount="<< s_instCount << endl;
@@ -178,22 +179,25 @@ KMixApplet::KMixApplet( const QString& configFile, Type t,
 
     /********** find out to use which mixer ****************************************/
     _mixer = 0;
-    if ( _mixerNum>=0 ) {
-	for (_mixer=s_mixers.first(); _mixer!=0; _mixer=s_mixers.next())
-	{
-	    // Name and number must match with the configuration
-	    if ( _mixer->mixerName() == _mixerName && _mixer->mixerNum()==_mixerNum ) break;
-	}
+    for (_mixer= Mixer::mixers().first(); _mixer!=0; _mixer=Mixer::mixers().next())
+    {
+      if ( _mixer->id() == _mixerId ) break;
+    }
+    if ( _mixer == 0 ) {
+      /* Until KMix V3.4-0 the mixerNumber (int) was stored. This was too complicated to handle, so we use an
+       * unique ID (_mixer->mixerId(). But in case when the user changes soundcards (or when upgrading from
+       * KMix 3.4-0 to a 3.4-1 or newer), we scan also for the soundcard name */
+      for (_mixer= Mixer::mixers().first(); _mixer!=0; _mixer=Mixer::mixers().next())
+      {
+	if ( _mixer->mixerName() == _mixerName ) break;
+      }
     }
 	
     // don't prompt for a mixer if there is just one available
-    if ( !_mixer && s_mixers.count() == 1 ) {
-	_mixer = s_mixers.first();
+    if ( !_mixer && Mixer::mixers().count() == 1 ) {
+	_mixer = Mixer::mixers().first();
     }
 	
-    //  Find out wether the applet should be reversed
-    //reversedDir = cfg->readBoolEntry("ReversedDirection", false);
-
 
 
     if ( _mixer == 0 )
@@ -221,11 +225,7 @@ KMixApplet::~KMixApplet()
    s_instCount--;
    if ( s_instCount == 0)
    {
-      QPtrListIterator<Mixer> it( s_mixers );
-      for ( ; it.current(); ++it )
-         it.current()->release();
-
-      s_mixers.clear();
+      MixerToolBox::deinitMixer();
    }
    */
 }
@@ -238,7 +238,7 @@ void KMixApplet::saveConfig()
         KConfig *cfg = this->config();
 	//kdDebug(67100) << "KMixApplet::saveConfig() save cfg=" << cfg << endl;
         cfg->setGroup( 0 );
-        cfg->writeEntry( "Mixer", _mixer->mixerNum() );
+        cfg->writeEntry( "Mixer", _mixer->id() );
         cfg->writeEntry( "MixerName", _mixer->mixerName() );
 
         cfg->writeEntry( "ColorCustom", _customColors );
@@ -265,7 +265,7 @@ void KMixApplet::loadConfig()
     KConfig *cfg = this->config();
     cfg->setGroup(0);
 	
-    _mixerNum = cfg->readNumEntry( "Mixer", -1 );
+    _mixerId = cfg->readEntry( "Mixer", "undef" );
     _mixerName = cfg->readEntry( "MixerName", QString::null );
 
     _customColors = cfg->readBoolEntry( "ColorCustom", false );
@@ -274,9 +274,9 @@ void KMixApplet::loadConfig()
     _colors.low = cfg->readColorEntry("ColorLow", &lowColor);
     _colors.back = cfg->readColorEntry("ColorBack", &backColor);
 
-    _colors.mutedHigh = cfg->readColorEntry("MutedColorHigh", &mutedHighColor);
-    _colors.mutedLow = cfg->readColorEntry("MutedColorLow", &mutedLowColor);
-    _colors.mutedBack = cfg->readColorEntry("MutedColorBack", &mutedBackColor);
+    _colors.mutedHigh = cfg->readColorEntry("ColorMutedHigh", &mutedHighColor);
+    _colors.mutedLow = cfg->readColorEntry("ColorMutedLow", &mutedLowColor);
+    _colors.mutedBack = cfg->readColorEntry("ColorMutedBack", &mutedBackColor);
 
     loadConfig( cfg, "Widget");
 }
@@ -311,7 +311,7 @@ void KMixApplet::selectMixer()
    QStringList lst;
 
    int n=1;
-   for (Mixer *mixer=s_mixers.first(); mixer!=0; mixer=s_mixers.next())
+   for (Mixer *mixer=Mixer::mixers().first(); mixer!=0; mixer=Mixer::mixers().next())
    {
       QString s;
       s.sprintf("%i. %s", n, mixer->mixerName().ascii());
@@ -325,7 +325,7 @@ void KMixApplet::selectMixer()
 					lst, 1, FALSE, &ok, this );
    if ( ok )
    {
-      Mixer *mixer = s_mixers.at( lst.findIndex( res ) );
+      Mixer *mixer = Mixer::mixers().at( lst.findIndex( res ) );
       if (!mixer)
          KMessageBox::sorry( this, i18n("Invalid mixer entered.") );
       else
