@@ -60,7 +60,7 @@ MDWSlider::MDWSlider(Mixer *mixer, MixDevice* md,
                                  bool small, Qt::Orientation orientation,
                                  QWidget* parent, ViewBase* mw, const char* name) :
     MixDeviceWidget(mixer,md,small,orientation,parent,mw,name),
-    m_linked(true), m_iconLabel( 0 ), m_muteLED( 0 ), m_recordLED( 0 ), m_label( 0 ), _layout(0)
+    m_linked(true), m_valueStyle( NNONE), m_iconLabel( 0 ), m_muteLED( 0 ), m_recordLED( 0 ), m_label( 0 ), _layout(0)
 {
 	// create actions (on _mdwActions, see MixDeviceWidget)
 
@@ -305,6 +305,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 			 slider->setMinimumSize( slider->sizeHint() );
 		 }
 
+		 slider->setBackgroundOrigin(AncestorOrigin);
 		 slider->installEventFilter( this );
 		 QToolTip::add( slider, m_mixdevice->name() );
 
@@ -415,6 +416,7 @@ MDWSlider::setIcon( int icontype )
    if( !m_iconLabel )
    {
       m_iconLabel = new QLabel(this);
+      m_iconLabel->setBackgroundOrigin(AncestorOrigin);
       installEventFilter( m_iconLabel );
    }
 
