@@ -1,6 +1,4 @@
 /***************************************************************************
-                          krecglobal.cpp  -  description
-                             -------------------
     copyright            : (C) 2003 by Arnold Krille
     email                : arnold@arnoldarts.de
  ***************************************************************************/
@@ -56,7 +54,7 @@ QWidget* KRecGlobal::mainWidget() { return _qwidget; }
 KConfig* KRecGlobal::kconfig() { return kapp->config(); }
 
 void KRecGlobal::setStatusBar( KStatusBar *bar ) { _statusbar = bar; }
-void KRecGlobal::message( QString text ) { if ( _statusbar ) _statusbar->message( text, 2000 ); }
+void KRecGlobal::message( const QString &text ) { if ( _statusbar ) _statusbar->message( text, 2000 ); }
 
 bool KRecGlobal::registerExport( KRecExportItem* item ) {
 	//kdDebug( 60005 ) << k_funcinfo << "About to register ExportItem for \"" << item->exportFormat() << "\" extensions:\"" << item->extensions() << "\"" << endl;
@@ -67,7 +65,7 @@ bool KRecGlobal::registerExport( KRecExportItem* item ) {
 	return true;
 }
 
-KRecExportItem* KRecGlobal::getExportItem( QString exportFormat ) {
+KRecExportItem* KRecGlobal::getExportItem( const QString &exportFormat ) {
 	KRecExportItem *tmp = _exports->find( exportFormat );
 	return tmp->newItem();
 }
@@ -90,7 +88,7 @@ QString KRecGlobal::exportFormatEndings() const {
 	return out;
 }
 
-KRecExportItem* KRecGlobal::getExportItemForEnding( QString ending ) {
+KRecExportItem* KRecGlobal::getExportItemForEnding( const QString &ending ) {
 	KTrader::OfferList offers = KTrader::self()->query( "KRec/exportplugin" );
 	KTrader::OfferList::iterator it = offers.begin();
 	while (  it!=offers.end() ) {
