@@ -29,6 +29,10 @@
 #include <sys/types.h>
 #include <sys/time.h>
 
+#ifndef timerclear
+#define timerclear(tvp) ((tvp)->tv_sec = (tvp)->tv_usec = 0)
+#endif
+
 int	playing = 0;		/* Should the CD be playing now? */
 
 /*
@@ -414,7 +418,10 @@ main(argc, argv)
 	 * superuser access.
 	 */
 	nice(-14);
+	setgid(getgid());
 	setuid(getuid());
+	if (getuid() != geteuid())
+		return 255;
 
 	FD_ZERO(&dummyfd);
 	FD_ZERO(&readfd);
