@@ -19,7 +19,7 @@
 
 
 
-#include <iostream.h>
+#include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -33,8 +33,7 @@
 #include <getopt.h>
 #endif
 
-
-
+using namespace std;
 
 void control_vorbis(InputInterface* input,OutputInterface* output,
 		   InputDecoder* decoder) {
