@@ -17,7 +17,9 @@
 #define _RESYNC_STATE_NEED_PACKET         1
 #define _RESYNC_STATE_NEED_START          2
 
+#include <iostream>
 
+using namespace std;
 
 
 MpegSystemStream::MpegSystemStream(InputStream* input) {
