@@ -13,7 +13,9 @@
 
 #include "mpegVideoBitWindow.h"
 
+#include <iostream>
 
+using namespace std;
 
 
 MpegVideoBitWindow::MpegVideoBitWindow() {
