@@ -855,7 +855,7 @@ void Mpegtoraw::layer3dequantizesample(int ch,int gr,
   REAL globalgain=POW2[gi->global_gain];
   REAL *TO_FOUR_THIRDS=TO_FOUR_THIRDSTABLE+FOURTHIRDSTABLENUMBER;
   int arrayEnd=nonzero[ch];
-  /* choose correct scalefactor band per block type, initalize boundary */
+  /* choose correct scalefactor band per block type, initialize boundary */
   /* and apply formula per block type */
   if(!gi->generalflag) {
     /* LONG blocks: 0,1,3 */
@@ -906,8 +906,8 @@ void Mpegtoraw::layer3dequantizesample(int ch,int gr,
 
 
 	do{
-	  out[0][index]=factor*TO_FOUR_THIRDS[in[0][index++]];
-	  out[0][index]=factor*TO_FOUR_THIRDS[in[0][index++]];
+	  out[0][index]=factor*TO_FOUR_THIRDS[in[0][index]];index++;
+	  out[0][index]=factor*TO_FOUR_THIRDS[in[0][index]];index++;
 	}while(--count);
       }
       cb++;
