@@ -16,14 +16,6 @@
 
 #include "ditherDef.h"
 
-#ifdef __GNUC__
-#if (__GNUC__ < 2 || ( __GNUC__ == 2 && __GNUC_MINOR__ < 91 ) )
-#warning "inline code disabled! (buggy egcs version)"
-#undef __NO_MATH_INLINES
-#define __NO_MATH_INLINES 1
-#endif
-#endif
-#include <math.h>
 
 
 
