@@ -14,6 +14,10 @@
 
 #include "yuvPicture.h"
 
+#include <iostream>
+
+using namespace std;
+
 static int instanceCnt=0;
 
 YUVPicture::YUVPicture(int width,int height) {
@@ -130,7 +134,7 @@ TimeStamp* YUVPicture::getWaitTime() {
   return waitTime;
 }
 
-void YUVPicture::setEarylTime(TimeStamp* earlyTime) {
+void YUVPicture::setEarlyTime(TimeStamp* earlyTime) {
   this->earlyTime=earlyTime;
 }
 
