@@ -16,16 +16,28 @@
 
 #if defined WIN32
 // usec goes from 0 -> 1000000 (one Million) under Unix
-#define gettimeofday(x,y) {                           \
-            struct _timeb tb;                         \
-            _ftime(&tb);                              \
-            tv->tv_sec=tb.time;                       \
-            tv->tv_usec=1000*tb.millitm;              \
-        }
-
+int gettimeofday(struct timeval *tv, struct timezone *tz) {
+  if(tv) {
+    struct _timeb tb;                         
+    _ftime(&tb);                              
+    tv->tv_sec=tb.time;                       
+    tv->tv_usec=1000*tb.millitm;   
+  }
+  return(0);
+}
 
+void abs_usleep(const timeval* tm) {
+  _sleep((tm->tv_usec / 1000) + (tm->tv_sec * 1000));
+}
 #endif
 
+#ifndef WIN32
+
+void abs_usleep(struct timeval* tm) {
+  select(0,NULL,NULL,NULL,tm);
+}
+
+#endif
 
 TimeWrapper::TimeWrapper() {
 }
@@ -53,7 +65,7 @@ void TimeWrapper::usleep(timeval_t* time) {
   waitTime.tv_sec=time->tv_sec;
   waitTime.tv_usec=time->tv_usec;
   /*Threads and usleep does not work, select is very portable*/
-  select(0,NULL,NULL,NULL,&waitTime);
+  ::abs_usleep(&waitTime);
 }
 
 
