@@ -12,7 +12,7 @@
 
 #include "vcdPlayObject_impl.h"
 #include "debug.h"
-
+#include <iostream>
 
 
 VCDPlayObject_impl::VCDPlayObject_impl() {
@@ -25,7 +25,7 @@ VCDPlayObject_impl::~VCDPlayObject_impl() {
 
 
 DecoderPlugin* VCDPlayObject_impl::createPlugin() {
-  cout << "VCDPlayObject_impl::getPlugin"<<endl;
+    std::cout << "VCDPlayObject_impl::getPlugin"<<std::endl;
   return new MpgPlugin();
 }
 
