@@ -246,6 +246,7 @@ QStrList Effects::available() const
 	Arts::TraderQuery query;
 	query.supports("Interface", "Arts::StereoEffect");
 	query.supports("Interface", "Arts::SynthModule");
+	query.supports("Use", "directly");
 	vector<Arts::TraderOffer> *offers = query.query();
 	for (vector<Arts::TraderOffer>::iterator i=offers->begin(); i!=offers->end(); i++)
 	{
@@ -281,4 +282,4 @@ QPtrList<Effect> Effects::effects() const
 #undef stack
 #undef engine
 
-#include "noatun/effects.moc"
+#include "effects.moc"
