@@ -68,18 +68,16 @@ public:
 public slots:
 	void loadSkin(const QString &file);
 	void readConfig();
-	void switchToDockmode(void);
-	void returnFromDockmode(void);
+	void switchToDockmode();
+	void returnFromDockmode();
 
 protected:
-	void unloadSkin(void);
-	void showSplash(void);
+	void unloadSkin();
+	void showSplash();
 
 public slots:
-	void timeUpdate(void);
-	void newSong(void);
-	void playlistHidden(void);
-	void playlistShown(void);
+	void timeUpdate();
+	void newSong();
 
 private slots:
 	void loadSeeker();
@@ -106,12 +104,12 @@ public:
 	static KJLoader* kjofol;
 
 private:
-	/* ==== docking stuff ==== */
+	// ==== docking stuff ====
 	KWinModule *mWin;
 	WId mDockToWin;
 	int mDockPositionX, mDockPositionY, mDockPosition;
 	QRect mDockWindowRect;
-	/* ==== end of docking stuff ==== */
+	// ==== end of docking stuff ====
 	bool moving;
 	QPoint mMousePoint;
 	QPtrList<KJWidget> subwidgets;
