@@ -9,6 +9,7 @@
 #include <qobject.h>
 
 class KFileMetaInfo;
+class KAction;
 
 class MetaTagLoader:public QObject, public Tags, public Plugin {
   Q_OBJECT
@@ -23,6 +24,7 @@ class MetaTagLoader:public QObject, public Tags, public Plugin {
   private:
     bool setProperty(KFileMetaInfo &info, PlaylistItem &item, const QString &key, const QString &property);
     int menuID;
+	 KAction *mAction;
 };
 
 #endif
