@@ -16,8 +16,10 @@
 #include <noatun/engine.h>
 #include <noatun/player.h>
 #include <noatun/stdaction.h>
+
 #include <kconfig.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kurldrag.h>
@@ -25,7 +27,9 @@
 #include <kpopupmenu.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
+#include <kstdguiitem.h>
 #include <kurl.h>
+
 #include <qaccel.h>
 #include <qdragobject.h>
 #include <qhbox.h>
@@ -34,6 +38,7 @@
 #include <qstrlist.h>
 #include <qtooltip.h>
 #include <qvbox.h>
+
 #include "userinterface.h"
 
 #include "back.xpm"
@@ -44,9 +49,8 @@
 #include "stop.xpm"
 #include "volume.xpm"
 
-
 SimpleUI::SimpleUI()
-     : KMainWindow(), UserInterface()
+     : KMainWindow(0, "NoatunSimpleUI"), UserInterface()
 {
     setAcceptDrops( true );
     setCaption( i18n("Noatun") );
@@ -55,34 +59,9 @@ SimpleUI::SimpleUI()
     setupCentralWidget();
     setupActions();
 
-    // Setup menu items and default menus
-    QPopupMenu *file = new QPopupMenu( this );
-    action( "file_open" )->plug( file );
-    file->insertSeparator();
-    action( "file_properties" )->plug( file );
-    file->insertSeparator();
-    action( "file_quit" )->plug( file );
-    menuBar()->insertItem( i18n("&File"), file );
-    QPopupMenu *view = new QPopupMenu( this );
-    video->action( "half_size" )->plug( view );
-    video->action( "normal_size" )->plug( view );
-    video->action( "double_size" )->plug( view );
-    view->insertSeparator();
-    video->action( "fullscreen_mode" )->plug( view );
-    menuBar()->insertItem( i18n("&View"), view );
-    QPopupMenu *settings = new QPopupMenu( this );
-    action( "show_playlist" )->plug( settings );
-    settings->insertSeparator();
-    action( "options_configure" )->plug( settings );
-    action( "effects" )->plug( settings );
-    action( "equalizer" )->plug( settings );
-    menuBar()->insertItem( i18n("&Settings"), settings );
-    menuBar()->insertItem( i18n("&Actions"), napp->pluginMenu() );
-    menuBar()->insertItem( i18n("&Help"), helpMenu() );
-
     contextMenu = video->popupMenu( this );
 
-    statusBar()->show();
+    setupGUI( StatusBar|Create, "simpleui.rc" );
 
     connect( napp->player(), SIGNAL(playing()), SLOT(slotPlaying()) );
     connect( napp->player(), SIGNAL(stopped()), SLOT(slotStopped()) );
@@ -109,13 +88,13 @@ SimpleUI::SimpleUI()
     QString str = config.readEntry( "View", "NormalSize" );
 
     if (str == "HalfSize")
-	video->setHalfSize();
+        video->setHalfSize();
     else if (str == "NormalSize")
-	video->setNormalSize();
+        video->setNormalSize();
     else if (str == "DoubleSize")
-	video->setDoubleSize();
+        video->setDoubleSize();
     else
-	applyMainWindowSettings( &config, "Simple" );
+        applyMainWindowSettings( &config, "Simple" );
 
     // PlayObject could be running, update video widget
     slotChanged();
@@ -131,31 +110,62 @@ SimpleUI::~SimpleUI()
     QString str;
 
     if (video->isHalfSize())
-	str = "HalfSize";
+        str = "HalfSize";
     else if (video->isNormalSize())
-	str = "NormalSize";
+        str = "NormalSize";
     else if (video->isDoubleSize())
-	str = "DoubleSize";
+        str = "DoubleSize";
     else
-	str = "CustomSize";
+        str = "CustomSize";
 
     config.writeEntry( "View", str );
+    config.sync();
 }
 
+
+
 void SimpleUI::setupActions()
 {
-    KStdAction::open( napp, SLOT(fileOpen()), actionCollection() );
-    KStdAction::quit( napp, SLOT(quit()), actionCollection() );
-    NoatunStdAction::playlist( actionCollection(), "show_playlist" );
-    KStdAction::preferences( napp, SLOT(preferences()), actionCollection() );
+    KStdAction::open( napp, SLOT(fileOpen()), actionCollection(), "_file_open" );
+    new KAction( i18n("&Properties"), 0, propertiesDialog, SLOT(show()),
+        actionCollection(), "_file_properties" );
+    KStdAction::quit( napp, SLOT(quit()), actionCollection(), "_file_quit");
+
+     NoatunStdAction::playlist( actionCollection(), "view_playlist" );
+    actionCollection()->insert(video->action( "half_size" ));
+    actionCollection()->insert(video->action( "normal_size" ));
+    actionCollection()->insert(video->action( "double_size" ));
+    actionCollection()->insert(video->action( "fullscreen_mode" ));
+
+    actionCollection()->insert(napp->pluginActionMenu());
+
+    menubarAction = KStdAction::showMenubar(this, SLOT(showMenubar()),
+        actionCollection());
+    statusbarAction = KStdAction::showStatusbar(this, SLOT(showStatusbar()),
+        actionCollection());
     NoatunStdAction::effects( actionCollection(), "effects" );
     NoatunStdAction::equalizer( actionCollection(), "equalizer" );
-
-    new KAction( i18n("&Properties..."), 0,
-		 propertiesDialog, SLOT(show()),
-		 actionCollection(), "file_properties" );
+    NoatunStdAction::loop( actionCollection(), "loop_style" );
+    KStdAction::preferences( napp, SLOT(preferences()), actionCollection() );
 }
 
+void SimpleUI::showMenubar()
+{
+    if(menubarAction->isChecked())
+        menuBar()->show();
+    else
+        menuBar()->hide();
+}
+
+void SimpleUI::showStatusbar()
+{
+    if(statusbarAction->isChecked())
+        statusBar()->show();
+    else
+        statusBar()->hide();
+}
+
+
 void SimpleUI::setupCentralWidget()
 {
     QVBox *npWidget = new QVBox( this );
@@ -169,9 +179,9 @@ void SimpleUI::setupCentralWidget()
 
     video = new VideoFrame( npWidget );
     connect( video, SIGNAL(adaptSize(int,int)),
-	     SLOT(slotAdaptSize(int,int)) );
+         SLOT(slotAdaptSize(int,int)) );
     connect( video, SIGNAL(rightButtonPressed(const QPoint &)),
-	     SLOT(slotContextMenu(const QPoint &)) );
+         SLOT(slotContextMenu(const QPoint &)) );
 
     QHBox *ctlFrame = new QHBox( npWidget );
     ctlFrame->setFixedHeight( 38 );
@@ -264,11 +274,8 @@ void SimpleUI::dragEnterEvent( QDragEnterEvent *event )
 void SimpleUI::dropEvent( QDropEvent *event )
 {
     KURL::List uri;
-
     if (KURLDrag::decode( event, uri ))
-    {
-	napp->player()->openFile( uri, false );
-    }
+        napp->player()->openFile( uri, false );
 }
 
 void SimpleUI::slotAdaptSize( int width, int height )
@@ -283,7 +290,7 @@ void SimpleUI::slotPlaying()
     slider->setEnabled( true );
 
     if (napp->player()->current())
-	statusBar()->message( napp->player()->current().title() );
+        statusBar()->message( napp->player()->current().title() );
 }
 
 void SimpleUI::slotStopped()
@@ -306,9 +313,9 @@ void SimpleUI::slotTimeout()
 {
     if (napp->player()->current() && !slider->currentlyPressed())
     {
-	positionLabel->setText( napp->player()->lengthString() );
-	slider->setRange( 0, (int)napp->player()->getLength() / 1000 );
-	slider->setValue( (int)napp->player()->getTime() / 1000 );
+        positionLabel->setText( napp->player()->lengthString() );
+        slider->setRange( 0, (int)napp->player()->getLength() / 1000 );
+        slider->setValue( (int)napp->player()->getTime() / 1000 );
     }
 }
 
@@ -320,7 +327,7 @@ void SimpleUI::slotSkipTo( int sec )
 void SimpleUI::slotChanged()
 {
     propertiesDialog->setPlayObject( napp->player()->current(),
-				     napp->player()->engine()->playObject() );
+        napp->player()->engine()->playObject() );
 }
 
 void SimpleUI::slotContextMenu( const QPoint &pos )
@@ -331,7 +338,7 @@ void SimpleUI::slotContextMenu( const QPoint &pos )
 void SimpleUI::slotSliderMoved( int sec )
 {
     if (napp->player()->current())
-	positionLabel->setText( napp->player()->lengthString( sec * 1000 ) );
+        positionLabel->setText( napp->player()->lengthString( sec * 1000 ) );
 }
 
 void SimpleUI::slotVolumeChanged( int volume )
@@ -344,15 +351,23 @@ void SimpleUI::slotVolumeFrame()
 {
     if (volumeFrame->isVisible())
     {
-	volumeFrame->hide();
+        volumeFrame->hide();
     }
     else
     {
-	int x = (volumeButton->width() - volumeFrame->width()) / 2;
-	int y = -(volumeFrame->height() + 5);
+        int x = (volumeButton->width() - volumeFrame->width()) / 2;
+        int y = -(volumeFrame->height() + 5);
 
-	volumeFrame->move( volumeButton->mapToGlobal( QPoint( x, y ) ) );
-	volumeFrame->show();
+        QPoint point( volumeButton->mapToGlobal( QPoint( x, y ) ) );
+        QRect deskRect = KGlobalSettings::desktopGeometry( point );
+
+        bool bottom = (point.y() + volumeFrame->height()) > (deskRect.y() + deskRect.height());
+        bool right = (point.x() + volumeFrame->width()) > (deskRect.x() + deskRect.width());
+
+        volumeFrame->move(
+            right ? (deskRect.x() + deskRect.width()) - volumeFrame->width() : ( point.x() < 0 ? 0 : point.x() ),
+            bottom ? (deskRect.y() + deskRect.height()) - volumeFrame->height() : ( point.y() < 0 ? 0 : point.y() ) );
+        volumeFrame->show();
     }
 }
 
