@@ -57,10 +57,8 @@
 
 WaSkin *_waskin_instance = NULL;
 
-WaSkin::WaSkin() : UserInterface()
+WaSkin::WaSkin() : QWidget(0, "NoatunWinampSkin"), UserInterface()
 {
-    NOATUNPLUGINC(WaSkin);
-
     mJumpPressed = false;
     mVolumePressed = false;
     mBalancePressed = false;
