@@ -1,7 +1,7 @@
 #ifndef OGGPLAYER_IMPL_H
-#define OGGPLAYER_IMPL_H "$Id: oggPlayObject_impl.h 185834 2002-10-27 01:10:28Z pfeiffer $"
+#define OGGPLAYER_IMPL_H "$Id: oggPlayObject_impl.h 674869 2007-06-13 10:18:09Z hasso $"
 
-#if defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED)
+#if defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED) || defined(__DragonFly__)
 /* union semun is defined by including <sys/sem.h> */
 #else
 /* according to X/OPEN we have to define it ourselves */
